@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '2.90';
+$VERSION = '2.91';
 
 require 5.008;
 use strict;
@@ -11,7 +11,7 @@ use Carp;
 use Symbol 'gensym','qualify_to_ref';   # For the 'any data type' hack
 use Fcntl qw( SEEK_SET SEEK_CUR );
 
-use List::Util qw(any none);
+use List::Util 1.33 qw(any none);
 
 use File::Basename qw( dirname );
 use File::Temp qw/ tempfile /;
@@ -2231,7 +2231,7 @@ Config::IniFiles - A module for reading .ini-style configuration files.
 
 =head1 VERSION
 
-version 2.90
+version 2.91
 
 =head1 SYNOPSIS
 
